<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2021 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Aug 12, 2021
 */

/**
 * @package InterWorx
 * @subpackage
 */
class Model_AcronisUtil
{

    /**
     * Expects string ending with unit (B/KB/GB)
     *
     * @param string $size
     */
    public static function toBytes($size)
    {
        $size = explode(' ', $size);
        $amount = $size[0];
        $unit = $size[1];

        $multiplyWith = self::_getMultiplyWith($unit);
        return $amount * $multiplyWith;
    }

    /**
     * @param string $unit
     */
    private static function _getMultiplyWith($unit)
    {
        $units = array('B'=>0, 'KB'=>1, 'MB'=>2, 'GB'=>3, 'TB'=>4, 'PB'=>5, 'EB'=>6, 'ZB'=>7, 'YB'=>8);

        if (!in_array($unit, array_keys($units))) {
            throw new Exception_Acronis_AcronisUtil("Model_AcronisUtil::toBytes failed: Unknown unit: $unit");
        }

        return pow(1024, $units[$unit]);
    }

    /**
     * @param string $path
     * @return string
     */
    public static function getOwner($path)
    {
        $cmd = "stat -c '%U' $path";
        $Command = new Command($cmd);
        $Command->allowQuoteSingle();
        $Command->runAsRoot();
        $Command->exec();

        self::_verifyCommandSuccessful($Command);

        $result = $Command->getOutput();
        $owner = $result[0];

        return $owner;
    }

    /**
     * Update ownership of file/directory.
     *
     * @param string $path
     * @param string $user
     */
    public static function chown($path, $user)
    {
        $chown = "chown $user:$user $path";
        $Command = new Command($chown);

        $Command->allowColon();
        $Command->runAsRoot();
        $Command->exec();

        self::_verifyCommandSuccessful($Command);
    }

    /**
     * @param Command $Command
     */
    private static function _verifyCommandSuccessful(Command $Command)
    {
        if (!$Command->wasSuccessful()) {
            throw new Exception('Command not successful: ' . $Command->getScrubbedCmd());
        }
    }
}
