<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Apr 14, 2020
 */


/**
 * Acronis API base for dashboard/backups/operations.
 *
 * @package Interworx
 * @package Plugin_Acronis
 */
abstract class Model_Api
{
    /**
     * Get cookie auth api.
     *
     * @return Model_ApiClient_CookieAuth
     */
    protected function _getCookieClient()
    {
        return $this->_getPlugin()->getCookieAuthApi();
    }


    /**
     * Get oauth api.
     *
     * @return Model_ApiClient_Interface
     */
    protected function _getOAuthClient()
    {
        return $this->_getPlugin()->getOAuthApiClient();
    }

    /**
     * Get plugin.
     *
     * @return Plugin
     */
    protected function _getPlugin()
    {
        return IW::PluginManager()->getPlugin('acronis');
    }

    /**
     * @return Model_Cache
     */
    protected function _getCache()
    {
        return $this->_getPlugin()->getCache();
    }

    /**
     * @return string
     */
    protected function _getInstanceId()
    {
        $this->_cacheResourceAndInstanceId();
        return $this->_getCache()->getInstanceId();
    }

    /**
     * @return string
     */
    protected function _getResourceId()
    {
        $this->_cacheResourceAndInstanceId();
        return $this->_getCache()->getResourceId();
    }

    /**
     * Make sure values are cached.
     */
    private function _cacheResourceAndInstanceId()
    {
        $Cache = $this->_getCache();
        $instanceId = $Cache->getInstanceId();
        $resourceId = $Cache->getResourceId();

        if (empty($instanceId) || empty($resourceId)) {
            $Api = new Model_Server_Api();
            $apiResponse = $Api->getDevice();
            $Cache->cacheResourceId($apiResponse['id']);
            $Cache->cacheInstanceId($apiResponse['instanceId']);
        }
    }
}
