<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Dec 22, 2020
 */

/**
 * @package InterWorx
 * @subpackage Plugin
 */
class Model_ApiResponse_Task
{
    private $_res;
    private $_progress;
    private $_id;
    private $_uuid;
    private $_state;
    private $_codeType;
    private $_codeError;
    private $_errorMessage;
    private $_errorDetails;
    private $_errorDetected;

    /**
     * @param array $res
     */
    public function __construct(array $res)
    {
        $blockers = $res['context']['_runtime']['legacyBlockers'][0];

        if (!empty($blockers)) {
            $this->_errorDetails = $blockers['Details'];
            $this->_errorMessage = $blockers['Message'];
            $this->_errorDetected = true;
        }

        $this->_res = $res;
        $this->_progress = $res['progress'];
        $this->_id = $res['id'];
        $this->_uuid = $res['uuid'];
        $this->_state = $res['state'];
        $this->_codeType = $res['result']['code'];
        $this->_codeError = $res['result']['error']['code'];
    }

    /**
     * @return boolean
     */
    public function getCodeType()
    {
        return $this->_codeType;
    }

    /**
     * @return boolean
     */
    public function getCodeError()
    {
        return $this->_codeError;
    }

    /**
     * @return boolean
     */
    public function errorDetected()
    {
        return $this->_errorDetected === true;
    }

    /**
     * @return string
     */
    public function getErrorMessage()
    {
        return $this->_errorMessage;
    }

    /**
     * @return string
     */
    public function getErrorDetails()
    {
        return $this->_errorDetails;
    }

    /**
     * @return string
     */
    public function getId()
    {
        return $this->_id;
    }

    /**
     * @return string
     */
    public function getUuid()
    {
        return $this->_uuid;
    }

    /**
     * @return string
     */
    public function getProgressPercent()
    {
        $percentage = $this->_progress['current'];
        return "$percentage%";
    }

    /**
     * @return string
     */
    public function getState()
    {
        return $this->_state;
    }

    /**
     * @return array
     */
    public function getRawResponse()
    {
        return $this->_res;
    }
}
