<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Aug 28, 2020
 */

/**
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Model_Recovery_Files_Nodeworx extends Model_Recovery_Files
{
    /**
     * Get root content.
     *
     * @return array
     */
    public function getRootContent()
    {
        return $this->_getRootContent();
    }

    /**
     * Get directory content by path.
     *
     * @param string $path
     * @return array
     */
    public function getDirectoryContent($path)
    {
        return $this->_getDirContentByPath($path);
    }

    /**
     * @param array   $paths
     * @param boolean $deleteNewerFiles
     */
    public function recoverDirectories(array $paths, $deleteNewerFiles = false)
    {
        $Dirs = $this->_getDirsWithLocalPathIndex($paths);
        $this->_recoverDirectories($Dirs, $deleteNewerFiles);
    }

    /**
     * @param array $paths
     */
    public function restoreToAltLocation(array $paths)
    {
        $Dirs = $this->_getDirsWithLocalPathIndex($paths);
        $ids = $this->_getDirIds($Dirs);
        $this->_restoreToAltLocation($ids);
    }

    /**
     * @param array $dirIds
     */
    private function _restoreToAltLocation(array $dirIds)
    {
        // YYYY-MM-DD-MM-SS
        $newDirName = date("Y-m-d-H-i-s");
        $path = self::NW_DOWNLOAD_DIR_PATH . "/$newDirName/";
        $this->_createRestoreAltLocationDir($path);
        $legacyId = $this->getLegacyId();
        $tenantAgentId = $this->getAgentTenantId();
        $Api = $this->_getRecoveryApi();
        $Api->recoverDirectoriesToAltLocation($legacyId, $tenantAgentId, $dirIds, $path);
    }

    /**
     * Get default location of file & db restores.
     *
     * @return string
     */
    public static function getDefaultRestorePath()
    {
        return self::NW_DOWNLOAD_DIR_PATH;
    }
}
